.. _datadb_forrestgump_audio:

****************************************************
Hanke et al. (2014): Forrest Gump audio movie (f)MRI
****************************************************

tba

Terms Of Use
============

All data are made available under the terms of the `Public Domain Dedication
and Licence`_ (PDDL).  In short this means that anybody is free to download and
use this dataset for any purpose, as well as to produce and re-share derived
data artifacts.

While not legally required, the authors hope that all users of the data will
acknowledge the original authors by citing the associated publication, and
follow good scientific practice as laid out in the `ODC Attribution/Share-Alike
Community Norms`_.

.. _Public Domain Dedication and Licence: http://opendatacommons.org/licenses/pddl/1.0/
.. _ODC Attribution/Share-Alike Community Norms: http://opendatacommons.org/norms/odc-by-sa/


Download
========

Data will be made available on http://www.openfmri.org

Usage
=====

Detailed information on the nature of the dataset is given in the data
descriptor. In order to facilitate re-use of this dataset a reference
implementation of a data access module has been made available at:

  https://github.com/hanke/gumpdata

This module include basic unit tests to check data integrity and consistency.

The source code used to create the group template images is available at:

  https://github.com/hanke/openfmri_helpers

The associate configuratiuon file is included in the ``gumpdata`` repository.


References
==========

tba
